@@ -12,11 +12,11 @@ class repertoire:
         if choix=="defaut":
             return self.chemin0
         if choix=="textures":
-            for d in [os.path.join(self.chemin0,"images"), "/usr/share/celestia/textures/medres"]:
-                if os.path.exists(d+'/earth.png'):
+            for d in [self.chemin0, "/usr/share/pysatellites"]:
+                if os.path.exists(d+'/images/earth-clouds.jpg'):
                     return d
-            print "erreur : pas de répertoire des planètes"
-            print "=== Il faudrait installer Celestia ==="
+            print ("erreur : pas de répertoire des planètes")
+            print ("=== Il manque les textures de Xplanet-images ===")
             raise(IOError)
         elif os.path.isdir(os.path.join(self.chemin0,choix)):
             return os.path.join(self.chemin0,choix)
